*** iodata.do
*** v 2.1
*** 24 Jun 2010
***
*** "Industry Effects of Government Spending"
*** Chris Nekarda and Valerie Ramey
***
*** Description:
***     Joins together data from IO tables for 1963, 1967, 1972, 1977, 1982, 1987, and 1992.
***     Fixes some missing IO observations
***
*** Requires:
***     ./iodata/iodataYYYY.dta
***     ./iodata/ioshipYYYY.dta
***     ./io-sic/iosic3.dta      (concordance between IO codes and SIC codes)
***
***************************************************************************************************
clear
set more off
tempfile iotemp1

** source data are in the markup directory

foreach yyyy in 1963 1967 1972 1977 1982 1987 1992 {
    noisily display as text "$S_DATE $S_TIME    year `yyyy'"
    use ./iodata/iodata`yyyy'.dta
    merge iocode4 using ./iodata/ioship`yyyy'.dta
    drop _merge
    sort iocode4
    merge iocode4 using ./io-sic/iosic3.dta, keep(sic4 desc)
    drop _merge
    capture confirm file `iotemp1'
    if _rc==0 append using `iotemp1'
    sort sic4 year
    qui save `iotemp1', replace
}
*
rename direct gdir
rename indirect gindir
note gtotal: gtotal = gdir+gindir
sort sic4 year
label var gdir "Direct shipments to government"
label var gindir "Indirect shipments to government"
label var gtotal "Total shipments to government"
label var vshipio "Total value of shipments in $1m (IO)"
order sic4 iocode4 year desc
sort sic4 year

*** FIX MISSING OBSERVATIONS IN THE IO DATA
** note: these observations are not in the original tables

* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
* !!! make sure to check the observation numbers if there are any changes to the IO data !!!
* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

* sic 2253
replace year=1987 in 266
* sic 3052
replace year=1963 in 727
replace year=1967 in 728
* sic 3341
replace year=1987 in 972
replace year=1992 in 973
* sic 3845
replace year=1963 in 1830
replace year=1967 in 1831
replace year=1972 in 1832
replace year=1977 in 1833
replace year=1982 in 1834
* sic 3565 doesn't exist
drop if sic4==3565

replace gdir=0 if gdir==.
replace gindir=0 if gindir==.
replace gtotal=gdir+gindir
replace vshipio=0 if vshipio==.

*** MERGE IN AGGREGATES
sort year
merge year using agg-gov-io.dta
drop _merge

label var year "Year"
label var gdir "Direct shipments to government in $1m"
label var gindir "Indirect shipments to government in $1m"
label var gtotal "Total shipments to government in $1m"
label var gdir_agg "Aggregate direct shipments to government in $1m"
label var gindir_agg "Aggregate Indirect shipments to government in $1m"
label var gtotal_agg "Aggregate total shipments to government in $1m"

format g* vshipio %10.1f
tsset sic4 year, y
compress
save iodata-v2.1.dta, replace
