clear
set memory 100m
set matsize 500
set more off

global data = "c:/docume~1/cnekarda/mydocu~1/ra/valerie/io/data"
global temp = "c:/temp"

use $data\iodataset-v2.3.dta

gen nw = (prodw/prodh)              // nominal wage
gen wp = (prodw/prodh)/piship       // real product wage
gen y = vship/piship                // real shipments
gen x = y/prodh                     // production worker productivity
gen h = prodh                       // production worker hours
gen avghr = prodh/prode             // averag hours per production worker
gen k = cap                         // capital stock
gen kh = k/h                        // capital per production worker
gen lshare = pay/vadd               // labor share
gen rvshipio = vshipio/piship       // real shipments (from IO data)
gen rgtotal = gtotal/piship         // real total government demand
gen rgdir = gdir/piship             // real direct government demand
gen rgindir = gindir/piship         // real indirect government demand
gen rgtotaly = rgtotal/rvshipio     // total real government demand as share of real shipments

keep if ioyear==1

local varlist = "nw wp y x h avghr k kh rvshipio rgtotal rgdir rgindir piship"

foreach var of local varlist {
    gen l`var' = ln(`var')

    by sic4: gen d`var' = (`var' - L5.`var')/5
    by sic4: replace d`var' = (`var' - L4.`var')/4 if year==1967

    by sic4: gen dl`var' = (l`var' - L5.l`var')/5
    by sic4: replace dl`var' = (l`var' - L4.l`var')/4 if year==1967
}

by sic4: gen flx = (F5.lx - lx)/5   // formerly dlxlead
by sic4: replace flx = (F4.lx - lx)/4 if year==1992

format dl* %05.4f

*PEROTTI'S METHOD
by sic4: gen drgtotaly = (rgtotal - L5.rgtotal)/(5*L5.rvshipio)
by sic4: replace drgtotaly = (rgtotal - L4.rgtotal)/(4*L4.rvshipio) if year==1967

*VARIATION ON PEROTTI'S METHOD #1
by sic4: gen drgtotalyb = (rgtotal - L5.rgtotal)/(5*(rvshipio+L5.rvshipio)/2)
by sic4: replace drgtotalyb = (rgtotal - L4.rgtotal)/(4*(rvshipio+L4.rvshipio)/2) if year==1967
by sic4: gen drgdiryb = (rgdir - L5.rgdir)/(5*(rvshipio+L5.rvshipio)/2)
by sic4: replace drgdiryb = (rgdir - L4.rgdir)/(4*(rvshipio+L4.rvshipio)/2) if year==1967

*ALTERNATIVE
by sic4: gen drgtotaldy = (rgtotal - L5.rgtotal)/(5*(rvshipio-L5.rvshipio))
by sic4: replace drgtotaldy = (rgtotal - L4.rgtotal)/(4*(rvshipio - L4.rvshipio)) if year==1967

/*
gen dlhk = -dlkh
*/

* REGRESSIONS
local gship = "drgtotalyb"

char year[omit] 1967
xi i.year
drop _Iyear_1963

* hours on govt shipments
reg dlh `gship'
*xi: reg dlh `gship' i.year i.sic4
xtreg dlh `gship' _I*, fe robust

* wages on govt shipments
reg dlwp `gship'
*xi: reg dlwp `gship' i.year i.sic4
xtreg dlwp `gship' _I*, fe robust

* wages on govt shipments and productivity
reg dlwp `gship' dlx
*xi: reg dlwp `gship' dlx i.year i.sic4
xtreg dlwp `gship' dlx _I*, fe robust

* markup on govt shipments
gen dlmarkup = dlx - dlwp
reg dlmarkup `gship'
*xi: reg dlmarkup `gship' i.year i.sic4
xtreg dlmarkup `gship' _I*, fe robust

* gov't shipments on productivity
reg `gship' dlx
xtreg `gship' dlx _I*, fe robust

* gov't shipments on lagged productivity and lagged gov't shipments
by sic4: gen Ldlx = L5.dlx
by sic4: gen L`gship' = L5.`gship'
reg `gship' Ldlx L`gship'
*xi: reg `gship' Ldlx L`gship' i.year i.sic4
xtreg `gship' Ldlx L`gship' _I*, fe robust

* IV regression wages on gov't shipments
ivreg dlwp (dlh=`gship')
*xi:ivreg dlwp i.year i.sic4 (dlh=`gship')
xtivreg dlwp (dlh=`gship') _I*, fe
