********************************************************************************
local progname = "makeio.do"
local v = "2.3"
* 10 Feb 2009 12:50
*
* Chris Nekarda
* cnekarda@ucsd.edu
*
********************************************************************************
set more off
clear
set mem 50m

noisily display as text c(current_date) " " c(current_time) "  begin `progname' (v`v')"

global code = "c:/work/code"
global data = "c:/work/data"
global temp = "c:/temp"

capture confirm file $data/iodataset-v`v'.dta
if _rc==0 erase $data/iodataset-v`v'.dta

noisily display as text c(current_date) " " c(current_time) "  processing productivity data"
capture confirm file $data/nber87.dta
if _rc!=0 noisily run $code/combinesic.do

noisily display as text c(current_date) " " c(current_time) "  processing IO direct/indirect data"
foreach yyyy in 1963 1967 1972 1977 1982 1987 1992 {
    noisily display as text c(current_date) " " c(current_time) "    year `yyyy'"
    capture confirm file $data/iodata/iodata`yyyy'.dta
    if _rc!=0 noisily run $code/make`yyyy'.do
    else use $data/iodata/iodata`yyyy'.dta
    merge iocode4 using $data/sic/iosic3.dta
    noi tab _merge
    drop _merge
    capture confirm file $temp/iotemp1.dta
    if _rc==0 append using $temp/iotemp1.dta
    sort sic4 year
    qui save $temp/iotemp1.dta, replace
}

merge sic4 year using $data/nber87.dta
drop _merge
drop if year==. | year==1997
sort sic4 year

label var year "Year"
rename direct gdir
label var gdir "Direct shipments to government"
rename indirect gindir
label var gindir "Indirect shipments to government"
label var gtotal "Total shipments to government"
note gtotal: gtotal = gdir+gindir
compress

save $data/iodataset-v`v'.dta, replace

noisily display as text c(current_date) " " c(current_time) "  processing IO total shipments data"
foreach yyyy in 1963 1967 1972 1977 1982 1987 1992 {
    noisily display as text c(current_date) " " c(current_time) "    year `yyyy'"
    capture confirm file $data/iodata/ioship`yyyy'.dta
    if _rc!=0 noisily run $code/ioship`yyyy'.do
    else use $data/iodata/ioship`yyyy'.dta
    capture confirm file $temp/iotemp2.dta
    if _rc==0 append using $temp/iotemp2.dta
    sort iocode4 year
    qui save $temp/iotemp2.dta, replace
}

merge iocode4 using $data/sic/iosic3.dta, keep(sic4)
keep sic4 year vshipio
sort sic4 year
qui save $temp/iotemp2.dta, replace

use $data/iodataset-v`v'.dta, replace
merge sic4 year using $temp/iotemp2.dta
tab _merge
drop _merge
tsset sic4 year, year

gen byte ioyear = cond(year==1963 | year==1967 | year==1972 | year==1977 | year==1982 | year==1987 | year==1992,1,0)
label var ioyear "Indicator for year with IO data"
format g* v* pi* %10.1f
order year sic3 sic4 iocode2 iocode4 desc gdir gindir gtotal
label var vshipio "Total value of shipments in $1m (IO)"
move vshipio vship

saveold $data/iodataset-v`v'.dta, replace
erase $temp/iotemp1.dta
erase $temp/iotemp2.dta

noisily display as text c(current_date) " " c(current_time) "  end `progname'"
set more on
