#delimit;
set more 1;
drop _all;

log using iolog.log, replace;

set memory 400m;

use vship.dta;
rename vship vship2;
rename total iovship;
sort sic4 year;
save junk.dta, replace;

clear;

use iodataset.dta;
rename _merge mergeio;

merge sic4 year using junk.dta;


*CORRECT THE SCALING ERROR IN 1982;

replace direct = direct/10 if year==1982;
replace indirect = indirect/10 if year==1982;
replace gtotal = gtotal/10 if year==1982;

sort sic4 year;

gen nw = (prodw/prodh); //nominal wage
gen wp = (prodw/prodh)/piship; //real product wage
gen y = vship/piship; //real shipments
gen x = y/prodh; //production worker productivity
gen h = prodh; //production worker hours
gen avghr = prodh/prode; //averag hours per production worker
gen k = cap; //capital stock
gen kh = k/h; //capital per production worker
gen lshare = pay/vadd; //labor share

*CREATING DIFFERENCES ACROSS IO SAMPLES;

gen dlx = (log(x) - log(x[_n-5]))/5 if year>=1963;


*CHRIS: CHANGE THIS;
gen dlxlead = (log(x[_n+5]) - log(x))/5 if year<=1991;

/*
gen dtfp = (log(y) - log(y[_n-5] 
    - lshare*log(h + (emp-prode)*avghr))
    + lshare[_n-5])*log(h[_n-5]+(emp[_n-5]-prode[_n-5])*avghr[_n-5])
    - (1 - lshare)*log(k) + (1-lshare[_n-5]/vadd[_n-5])/5 if year>62;
*/


drop if mergeio==1;

sort sic4 year;

gen riovship = iovship/piship; //real ioshipments
gen rgtotal = gtotal/piship; //real total government demand
gen rgdirect = direct/piship; //real direct government demand
gen rgindirect = indirect/piship; //real indirect government demand

gen rgtotaly = rgtotal/riovship; //total government demand ratio of shipments




*CREATE LOGS OF VARIABLES;
for z1 in varlist
  nw wp y x h avghr k kh riovship rgtotal rgdirect rgindirect 
\ z2 in newlist
 lnw lwp ly lx lh lavghr lk lkh lriovship lrgtotal lrgdirect 
  lrgindirect :
 gen z2 = log(z1);
 
for z1 in varlist
 lnw lwp ly lh lavghr lk lkh lriovship lrgtotal lrgdirect 
  lrgindirect 
\ z2 in newlist
 dlnw dlwp dly dlh dlavghr dlk dlkh dlriovship dlrgtotal 
  dlrgdirect dlrgindirect :
gen z2 = (z1 - z1[_n-1])/5 if year > 1967;

for z1 in varlist
  nw wp y x h avghr k kh rgtotal rgdirect rgindirect 
\ z2 in newlist
 dnw dwp dy dx dh davghr dk dkh drgtotal drgdirect
  drgindirect:
gen z2 = (z1 - z1[_n-1])/5 if year > 1967;


*PEROTTI'S METHOD;

gen drgtotaly = (rgtotal - rgtotal[_n-1])/(5*riovship[_n-1]) if year>1967;
replace drgtotaly = (rgtotal - rgtotal[_n-1])/(riovship[_n-1]*4) if year==1967;

*VARIATION ON PEROTTI'S METHOD;	

gen drgtotalyb = (rgtotal - rgtotal[_n-1])/(5*.5*(riovship+riovship[_n-1])) if year>1963;
replace drgtotalyb = (rgtotal - rgtotal[_n-1])/(4*.5*(riovship + riovship[_n-1])) if year==1967;

gen drgdirectyb = (rgdirect - rgdirect[_n-1])/(5*.5*(riovship+riovship[_n-1])) if year>1963;
replace drgdirectyb = (rgdirect - rgdirect[_n-1])/(4*.5*(riovship + riovship[_n-1])) if year==1967;


*ALTERNATIVE;

gen drgtotaldy = (rgtotal - rgtotal[_n-1])/(5*(riovship-riovship[_n-1])) if year>1963;
replace drgtotaldy = (rgtotal - rgtotal[_n-1])/(4*(riovship - riovship[_n-1])) if year==1967;


replace dly = (ly - ly[_n-1])/4 if year==1967;
replace dlx = (lx - lx[_n-1])/4 if year==1967;
replace dlwp = (lwp - lwp[_n-1])/4 if year==1967;
replace dlnw = (lnw - lnw[_n-1])/4 if year==1967;
replace dlh = (lh - lh[_n-1])/4 if year==1967;
replace dlavghr = (lavghr - lavghr[_n-1])/4 if year==1967;
replace dlk = (lk - lk[_n-1])/4 if year==1967;
replace dlkh = (lkh - lkh[_n-1])/4 if year==1967;
replace dlrgtotal = (lrgtotal - lrgtotal[_n-1])/4 if year==1967;

gen dlmarkup = dlx - dlwp;

gen dlhk = -dlkh;

gen dlxlag = dlx[_n-1] if year>1963;

gen drgtotalylag = drgtotaly[_n-1] if year>1963;

gen drgtotalyblag = drgtotalyb[_n-1] if year>1963;

reg dlh drgtotalyb;
xi:reg dlh drgtotalyb i.year i.sic4;

reg dlwp drgtotalyb;
xi:reg dlwp drgtotalyb i.year i.sic4;

reg dlwp drgtotalyb dlx;
xi:reg dlwp drgtotalyb dlx i.year i.sic4;

reg dlmarkup drgtotalyb ;
xi:reg dlmarkup drgtotalyb i.year i.sic4;

reg drgtotalyb dlx;
xi:reg drgtotalyb dlx i.year i.sic4;

reg drgtotalyb dlxlag drgtotalyblag;
xi:reg drgtotalyb dlxlag drgtotalyblag i.year i.sic4;

ivreg dlwp (dlh=drgtotalyb);
xi:ivreg dlwp i.year i.sic4 (dlh=drgtotalyb);


/*
reg dlwp dlh;

xi:reg dlwp dlh i.year i.sic4;

reg dlh drgtotalyb;

xi:reg dlh drgtotalyb i.sic4 i.year ;

reg dlwp drgtotalyb;

xi:reg dlwp drgtotalyb i.sic4 i.year ;



xi:reg dlwp dlhk i.sic4 i.year ;

reg drgtotalyb dlxlag;

reg drgtotalyb dlxlag drgtotalyblag;

xi:reg drgtotalyb dlxlag i.sic4 i.year;

xi:ivreg dlwp i.sic4 i.year (dlhk = drgtotalyb);

xi:ivreg dlwp i.sic4 i.year (dlh = drgtotalyb);

*/
/*

for z1 in varlist
  drgtotaly drgdirecty drgindirecty dfrgtotal dfrgdirect dfrgindirect
  drgtotaldy drgdirectdy drgindirectdy
\ z2 in newlist
  ndrgtotaly ndrgdirecty ndrgindirecty ndfrgtotal ndfrgdirect ndfrgindirect
  ndrgtotaldy ndrgdirectdy ndrgindirectdy:
 gen z2 = -z1;
 
sort ndrgtotaldy sic4 iocode4 year dlh dlx drgtotaly drgtotaly dfrgtotal;
gen dgdyrank = _n;

sort ndfrgtotal sic4 iocode4 year dlh dlx drgtotaly drgtotaly drgtotaldy;
gen dfrrank = _n;

sort ndrgtotaly sic4 iocode4 year dlh dlx drgtotaly drgtotaldy dfrgtotal;
gen perottirank = _n;

list desc sic4 year perottirank dfrrank dgdyrank in 1/30;

corr ndrgtotaly ndfrgtotal ndrgtotaldy;
*/
*/

*Perotti's industries;

/*
gen def = (sic==3483 | sic==3482 | sic==3489 | sic==3484 | sic==3674
  | sic==3675 | sic==3873 | sic==2951 | sic==3446 | sic==2861
  | sic==3573 | sic==3728 | sic==3724 | sic==3662 | sic==3629
  | sic==3761 | sic==3842); 
*/

*gen buildup = ((year>=65 & year<=67) | (year>=80 & year<=87));
*gen builddown = ((year>67 & year<72) | (year>87 & year<95));

*Now remove the two computer industries;

*replace def = 0 if sic==3674 | sic==3573;


log close;

