********************************************************************************
local progname = "makeio.do"
local v = "3.0"
* 30 Jan 2009
*
* Chris Nekarda
* cnekarda@ucsd.edu
*
********************************************************************************
set more off
clear
set mem 50m

noisily display as text c(current_date) " " c(current_time) "  begin `progname' (v`v')"

global datapath = "./data"
global temppath = "c:/temp"

noisily display as text c(current_date) " " c(current_time) "  processing productivity data"
capture confirm file $datapath/nber87.dta
if _rc!=0 do combinesic.do

noisily display as text c(current_date) " " c(current_time) "  processing IO direct/indirect data"
foreach yyyy in 1963 1967 1972 1977 1982 1987 1992 1997 {
    noisily display as text c(current_date) " " c(current_time) "    year `yyyy'"
    capture confirm file $datapath/iodata`yyyy'.dta
    if _rc!=0 {
        noisily run make`yyyy'.do
    }
    else use $datapath/iodata`yyyy'.dta
    merge iocode4 using $datapath/iosic3.dta
    noi tab _merge
    drop _merge
    capture confirm file $temppath/iotemp.dta
    if _rc==0 append using $temppath/iotemp.dta
    sort sic4 year
    qui save $temppath/iotemp.dta, replace
}

merge sic4 year using $datapath/nber87.dta
drop _merge
drop if year==.
sort sic4 year

label var year "Year"
label var direct "Direct shipments to government"
label var indirect "Indirect shipments to government"
label var gtotal "Total (direct+indirect) shipments to government"
drop comb
compress

save $datapath/iodataset-v`v'.dta, replace
erase $temppath/iotemp.dta

noisily display as text c(current_date) " " c(current_time) "  processing IO total shipments data"
foreach yyyy in 1963 1967 1972 1977 1982 1987 1992 1997 {
    noisily display as text c(current_date) " " c(current_time) "    year `yyyy'"
    capture confirm file $datapath/ioship`yyyy'.dta
    if _rc!=0 {
        noisily run ioship`yyyy'.do
    }
    else use $datapath/ioship`yyyy'.dta
    capture confirm file $temppath/iotemp.dta
    if _rc==0 append using $temppath/iotemp.dta
    sort iocode4 year
    qui save $temppath/iotemp.dta, replace
}

merge iocode4 using $datapath/iosic3.dta, keep(sic4)
keep sic4 year vshipio
sort sic4 year
qui save $temppath/iotemp.dta, replace

use $datapath/iodataset-v`v'.dta, replace
merge sic4 year using $temppath/iotemp.dta
erase $temppath/iotemp.dta
tab _merge
drop _merge
sort sic4 year

label var vshipio "Total value of shipments (IO)"
format direct indirect gtotal vship vshipio %10.1f
order year sic3 sic4 iocode2 iocode4 desc direct indirect gtotal
move vshipio vadd

save $datapath/iodataset-v`v'.dta, replace

noisily display as text c(current_date) " " c(current_time) "  end `progname'"
set more on
