use $data\iodataset-v2.2.dta, replace
drop if year==.

rename emp nt
rename prode np
move np pay
gen ns = nt-np
label var ns "Nonproduction workers in 1000s"
note ns: ns = nt-np
move ns pay
rename pay wt
rename prodw wp
move wp prodh
gen ws = wt-wp
label var ws "Nonproduction worker wages in $1m"
note ws: ws = wt-wp
move ws prodh
rename prodh hp

**********************************
* hours by nonproduction workers *
**********************************
* assumption 1: nonproduction workers work constant 2000 hours/year
gen hs = 2*ns
note hs: hs = 2*ns

* assumption 2: nonproduction workers work same hours/year as production workers
*gen hs = (hp/np)*ns
*note hs: hs = (hp/np)*ns

* data: ratio of hours worked by nonproduction to production estimated from MCPS
**NOTE: data for this do not exist yet**
*gen hs = nphratio*ns
*note hs: hs = nphratio*ns

label var hs "Nonproduction worker hours in 1m"
move hs vshipio
* total hours
gen ht = hp+hs
label var ht "Total worker hours in 1m"
note ht: ht = hp+hs
move ht hp

* aggregation weight
egen totship = sum(vship), by(year)
gen wgt = vship/totship
label var wgt "Aggregation weight (vship)"
drop totship

format ?? %10.1f

gen ry = vship/piship
label var ry "Real value of shipments in $1m"
note ry: ry = vship/piship
gen xt = ln(ry/ht)
label var xt "Labor productivity (all workers)"
note xt: xt = ln(ry/ht)
gen xp = ln(ry/hp)
label var xp "Labor productivity (production workers)"
note xp: xp = ln(ry/hp)
gen rwt = ln((wt/ht)/piship)
label var rwt "Real product wage (all workers)"
note rwt: rwt = ln((wt/ht)/piship)
gen rwp = ln((wp/hp)/piship)
label var rwp "Real product wage (production workers)"
note rwp: rwp = ln((wp/hp)/piship)

* DHP markup measure is price over marginal cost
gen pcm = (vship+D.invent-wt-matcost)/(vship+D.invent)
label var pcm "DHP markup"
note pcm: pcm = (vship+D.invent-wt-matcost)/(vship+D.invent)

* RW markup measure (inverse of labor share)
gen mut = xt-rwt
label var mut "RW markup (all workers)"
note mut: mut = xt-rwt
gen mup = xp-rwp
label var mup "RW markup (production workers)"
note mup: mup = xp-rwp

/* normalizes the RW measure (i.e. ln(\alpha)) to the 4-digit industry sample mean of the DHP measure
egen foo = mean(mut), by(sic4)
egen bar = mean(pcm), by(sic4)
qui replace mut = mut - (foo-bar)
qui replace mup = mup - (foo-bar)
drop foo bar
*/

/* calculates the change in the RW markup, then iterates the change from level of 1.2
gen dmut = -(D.xt-D.rwt)
label var dmut "Change in markup (all workers)"
note dmut: dmut = -(D.xt-D.rwt)
gen dmup = -(D.xp-D.rwp)
label var dmup "Change in markup (production workers)"
note dmup: dmup = -(D.xp-D.rwp)
capture confirm var mut
if _rc==0 drop mut
gen mut=1.2
capture confirm var mup
if _rc==0 drop mup
gen mup=1.2
tsfill, full
capture tab sic4, matrow(siccode)
local numsec = r(r)
local obs = 1
forvalues i = 1/`numsec' {
    local sic = siccode[`i',1]
    capture tab year if sic4==`sic'
    local years = r(r)-1
    local obs = `++obs'
    forvalues j = 1/`years' {
        *noi display mu[`obs'-1] " " dmu[`obs'] " " mu[`obs'-1] + dmu[`obs']
        qui replace mut = mut[`obs'-1] + dmut[`obs'] in `obs'
        qui replace mup = mup[`obs'-1] + dmup[`obs'] in `obs'
        local obs = `++obs'
    }
}
*/

/* aggregation: averages across all sectors, weighting by total shipments
collapse (mean) pcm mut mup [iw=wgt], by(year)
tsset year, y
*/
